@@ -415,7 +415,7 @@ public final class ImapIdlePushListener implements PushListener, Runnable {
                 } finally {
                     this.imapFolderInUse = null;
                     try {
-                        imapFolder.close(false);
+                        imapFolder.forceClose();
                     } catch (final Exception e) {
                         // Ignore
                     }
@@ -566,7 +566,7 @@ public final class ImapIdlePushListener implements PushListener, Runnable {
             if (null != imapFolderInUse) {
                 this.imapFolderInUse = null;
                 try {
-                    imapFolderInUse.close(false);
+                    imapFolderInUse.forceClose();
                 } catch (final Exception e) {
                     // Ignore
                 }
